@@ -1,34 +1,34 @@
-CreateClassObject<-function(simmap,rnd=5){
-  if(any(grepl("___",simmap$tip.label))){stop("script will not work with '___' in tip labels; remove extra underscores")}
+CreateClassObject<-function(map,rnd=5,return.mat=FALSE){
+  if(any(grepl("___",map$tip.label))){stop("script will not work with '___' in tip labels; remove extra underscores")}
   paste(rep(LETTERS,each=26),LETTERS,sep="")->TWOLETTERS
   paste(rep(TWOLETTERS,each=26),LETTERS,sep="")->THREELETTERS
-  nodeDist<-vector(mode = "numeric", length = simmap$Nnode)
-  totlen<-length(simmap$tip.label)
+  nodeDist<-vector(mode = "numeric", length = map$Nnode)
+  totlen<-length(map$tip.label)
   root <-totlen  + 1
-  heights<-nodeHeights(simmap)
-  for (i in 1:dim(simmap$edge)[1]){
-    nodeDist[[simmap$edge[i, 1] - totlen]] <- heights[i]
+  heights<-nodeHeights(map)
+  for (i in 1:dim(map$edge)[1]){
+    nodeDist[[map$edge[i, 1] - totlen]] <- heights[i]
   }
   nodeDist<-c(nodeDist,max(heights))
   nodeDiff<-diff(nodeDist)
   flag=0
   if(sum(nodeDiff<0)>0){  ##this loop renumbers the nodes if trees nodes are not placed in sequential order
-    node.order<-match(rank(heights[,1],ties.method="min"),seq(1, by = 2, len = simmap$Nnode))
+    node.order<-match(rank(heights[,1],ties.method="min"),seq(1, by = 2, len = map$Nnode))
     node.order<-node.order+totlen
-    old.edge<-simmap$edge
-    old.map<-simmap
-    simmap$edge[,1]<-node.order
-    for(j in 1:length(simmap$edge[,2])){
-      if(simmap$edge[j,2]>totlen){
+    old.edge<-map$edge
+    old.map<-map
+    map$edge[,1]<-node.order
+    for(j in 1:length(map$edge[,2])){
+      if(map$edge[j,2]>totlen){
         #match number order in old edge
         #lookup value in new edge
         #replace with value
-        simmap$edge[j,2]<-simmap$edge[,1][match(simmap$edge[j,2],old.edge[,1])]
+        map$edge[j,2]<-map$edge[,1][match(map$edge[j,2],old.edge[,1])]
       }
     }
     nodeDist<-vector()
-    for (i in 1:dim(simmap$edge)[1]){
-      nodeDist[[simmap$edge[i, 1] - totlen]] <- heights[i]
+    for (i in 1:dim(map$edge)[1]){
+      nodeDist[[map$edge[i, 1] - totlen]] <- heights[i]
     }
     nodeDist<-c(nodeDist,max(heights))
     nodeDiff<-diff(nodeDist)
@@ -36,8 +36,8 @@ CreateClassObject<-function(simmap,rnd=5){
   }
   mat<-matrix(nrow=0, ncol=3)
   counter_three_letters <- 0
-  for(i in 1:simmap$Nnode){
-    other<-simmap$edge[simmap$edge[,1]==i+totlen, 2]
+  for(i in 1:map$Nnode){
+    other<-map$edge[map$edge[,1]==i+totlen, 2]
     for(b in other){
       int<-matrix(ncol=3)
       int[1]<-i+totlen
@@ -46,18 +46,18 @@ CreateClassObject<-function(simmap,rnd=5){
         int[2]<-paste(".",THREELETTERS[counter_three_letters],sep="")
         int[3]<-b
       } else {
-        int[2]<-simmap$tip.label[[b]]
+        int[2]<-map$tip.label[[b]]
         int[3]<-0 
       }
       mat<-rbind(mat,int)
     }
   }
-  if(any(class(simmap)=="phylo")){
+  if(geiger::is.phylo(map)){
     for(i in 1:length(mat[,1])){
       if(mat[i,3]==0){
-        mat[i,3]<-as.character(match(mat[i,2],simmap$tip.label))
+        mat[i,3]<-as.character(match(mat[i,2],map$tip.label))
       }}	
-    maps.object<-simmap$maps
+    maps.object<-map$maps
     brchange<-vapply(maps.object,function(x) any(length(names(x))>1),1)
     if(sum(brchange)!=0){
       newtimes<-vector()
@@ -86,7 +86,7 @@ CreateClassObject<-function(simmap,rnd=5){
 			hold.m<-mat[as.numeric(mat[,1])<=(totlen+nodecount),c(2,3)]
 			int<-dim(hold.m)[1]
 			for(m in 1:int){
-				hold.m[m,2]<-names(maps.object[[which(simmap$edge[,2]==as.numeric(hold.m[m,2]))]])[1]
+				hold.m[m,2]<-names(maps.object[[which(map$edge[,2]==as.numeric(hold.m[m,2]))]])[1]
 			}
 			nat[[i]]<-hold.m
 			} else {
@@ -95,12 +95,13 @@ CreateClassObject<-function(simmap,rnd=5){
 				hold.m<-rbind(P[as.numeric(P[,2])<=totlen,],P[as.numeric(P[,2])>(totlen+nodecount),])
 				int<-dim(hold.m)[1]
 				for(m in 1:int){
-					iden<-which(simmap$edge[,2]==as.numeric(hold.m[m,2]))
+					iden<-which(map$edge[,2]==as.numeric(hold.m[m,2]))
 					if(brchange[iden]==0 || !(hold.m[m,1]%in%nat[[i-1]][,1])){
 						hold.m[m,2]<-names(maps.object[[iden]])[1]
 					} else{
 						num=1
-						while(round(nodeDist[i+1]-old.Dist[simmap$edge[iden,1]-totlen],6)>round(sum(maps.object[[iden]][1:num]),6)){
+						#while(round(nodeDist[i+1]-old.Dist[map$edge[iden,1]-totlen],6)>round(sum(maps.object[[iden]][1:num]),6)){
+						while((round(nodeDist[i+1]-old.Dist[map$edge[iden,1]-totlen],rnd)-round(sum(maps.object[[iden]][1:num]),rnd))>(2*(10^-rnd))){
 						num=num+1}
 						hold.m[m,2]<-names(maps.object[[iden]])[num]
 					}
@@ -111,12 +112,13 @@ CreateClassObject<-function(simmap,rnd=5){
 				hold.m<-rbind(P[as.numeric(P[,2])<=totlen,],P[as.numeric(P[,2])>(totlen+nodecount),])
 				int<-dim(hold.m)[1]
 				for(m in 1:int){
-					iden<-which(simmap$edge[,2]==as.numeric(hold.m[m,2]))
+					iden<-which(map$edge[,2]==as.numeric(hold.m[m,2]))
 					if(brchange[iden]==0 | !(hold.m[m,1]%in%nat[[i-1]][,1])){
 						hold.m[m,2]<-names(maps.object[[iden]])[1]
 					} else{					
 						num=1
-						while((round(nodeDist[i+1]-old.Dist[simmap$edge[iden,1]-totlen],rnd)-round(sum(maps.object[[iden]][1:num]),rnd))>(2*(10^-rnd))){
+						#while(round(nodeDist[i+1]-old.Dist[map$edge[iden,1]-totlen],5)>round(sum(maps.object[[iden]][1:num]),5)){
+						while((round(nodeDist[i+1]-old.Dist[map$edge[iden,1]-totlen],rnd)-round(sum(maps.object[[iden]][1:num]),rnd))>(2*(10^-rnd))){
 						num=num+1}
 						hold.m[m,2]<-names(maps.object[[iden]])[num]
 					}
@@ -127,6 +129,12 @@ CreateClassObject<-function(simmap,rnd=5){
 	if(nodeDist[i+1]%in%old.Dist){nodecount=nodecount+1}
 	}	
     }
+    
+
+  if(return.mat){
+	mat[which(mat[,3]==0),3]<-match(mat[which(mat[,3]==0),2],map$tip.label)
+	return(list(class.object=nat,times=round(nodeDist,8),spans=nodeDiff,mat=mat,phylo=map))
+  }else{
   return(list(class.object=nat,times=round(nodeDist,8),spans=nodeDiff))
-  
+  }
 }
\ No newline at end of file
