@@ -10,9 +10,9 @@ likelihood_t_MC<-function(phylo,data,par) #par[1]=sig2,par[2]=sterm
 		return(Inf)
 	} else{
   	op <- getOption("show.error.messages")
+    on.exit( options(show.error.messages=op) )
   	options(show.error.messages=FALSE)
 	IV=try(solve(V))
-  	options(show.error.messages=op)
   if(inherits(IV, "try-error")){
     IV=pseudoinverse(V)
   	if(max(IV)==0){return(Inf)}
