@@ -4,11 +4,7 @@
 #include <R.h>
 #include <Rinternals.h>
 #include <Rdefines.h>
-#include <R_ext/RS.h>
-#include <R_ext/Lapack.h>
-#include <R_ext/Utils.h>
-#include <R_ext/BLAS.h>
-#include <complex.h>
+
 
 static SEXP makearray (int rank, int *dim) {
   int nprotect = 0;
